@@ -21,10 +21,9 @@ def scenario(name: str, useconfig: bool = False):
         typer.echo(e)
     except Exception as err:
         traceback.print_tb(err.__traceback__)
-
-    reporter = Reporter()
-    if runner.scenario_passed():
-        reporter.publish(name, Reporter.status_passed)
-    else:
-        reporter.publish(name, Reporter.status_failed)
-        runner.driver.close()
+    finally:
+        reporter = Reporter()
+        if runner.scenario_passed():
+            reporter.publish(name, Reporter.status_passed)
+        else:
+            reporter.publish(name, Reporter.status_failed)
